//------------------------------------------------------------------------------
/* 
 * File:   Lcd4.h
 * Author: Chisanga Mumba
 */
//------------------------------------------------------------------------------
// This is a guard condition so that contents of this file are not included
// more than once.  
#ifndef LCD4_H
#define	LCD4_H
#include "Lcd4_prototypes.h"
//------------------------------------------------------------------------------
#include <xc.h> // include processor files - each processor file is guarded.  
//------------------------------------------------------------------------------
#define display_on      0x0C      //Cursor OFF, Blink off
#define display_off     0x08
#define cursor_on       0x0E
#define cursor_blink    0x0F
#define home            0x02
#define clear           0x01
#define auto_increment  0x06
#define auto_decrement  0x04
#define function_set    0x28       //DL = 0 <Data Lenghth> (4 bit mode). N = 1 <Num lines> (2 Lines).
#define font2           function_set | 0x04     //Set bit 3 only.
//-----------------------Follow Datasheet instructions--------------------------
void LCD_init()
{
  RS_dir = 0;
  EN_dir = 0;
  D4_dir = 0;
  D5_dir = 0;
  D6_dir = 0;
  D7_dir = 0;

  LCD_command(home);
  LCD_command(function_set);   
  LCD_command(display_on);      
  LCD_command(auto_increment);
}
//------------------------------------------------------------------------------
void LCD_write(char data)
{
  char pinBit[4];
  
  for(char i = 0; i < 4;i++)
  {
    pinBit[i] = ((data >> i) & 0x01);
  }
  
  D4 = pinBit[0];
  D5 = pinBit[1];
  D6 = pinBit[2];
  D7 = pinBit[3];
}
//------------------------------------------------------------------------------
void LCD_command(char command)
{
  RS = 0;                     //Instruction register ( commands ).
  LCD_write(command>>4);      //Higher Nibble
  latch();
  LCD_write(command);         //Lower Nibble
  latch();
}
//------------------------------------------------------------------------------
void LCD_data(char data)
{
  RS = 1;                     //Data register  ( Strings and characters ).
  LCD_write(data>>4);
  latch();
  LCD_write(data);
  latch();
}
//------------------------------------------------------------------------------
void LCD_string(char row, char column, char text[])
{
  LCD_command(rowAddr[row] + column);  //Set co-ordinates.
  while(*text)
  {
    LCD_data(*text++);
  }
}
//------------------------------------------------------------------------------
void LCD_character(char row, char column, char character)
{
  LCD_command(rowAddr[row] + column);
  LCD_data(character);
}
//------------------------------------------------------------------------------
void latch()
{
  EN  = 1;
  __delay_ms(5);
  EN  = 0;
}
//------------------------------------------------------------------------------
#endif
//------------------------------------------------------------------------------